GoogleMapsFlutterIOS class
An implementation of GoogleMapsFlutterPlatform for iOS.
- Inheritance
-
- Object
- PlatformInterface
- GoogleMapsFlutterIOS
Constructors
- GoogleMapsFlutterIOS({@visibleForTesting MapsApi apiProvider(int mapId)?})
- Creates a new Android maps implementation instance.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
hostMapHandlers
→ Map<
int, HostMapMessageHandler> -
The per-map handlers for callbacks from the host side.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
animateCamera(
CameraUpdate cameraUpdate, {required int mapId}) → Future< void> - Starts an animated change of the map camera position.
-
animateCameraWithConfiguration(
CameraUpdate cameraUpdate, CameraUpdateAnimationConfiguration configuration, {required int mapId}) → Future< void> -
Starts an animated change of the map camera position using the provided
CameraUpdateAnimationConfiguration. -
buildView(
int creationId, PlatformViewCreatedCallback onPlatformViewCreated, {required CameraPosition initialCameraPosition, Set< Marker> markers = const <Marker>{}, Set<Polygon> polygons = const <Polygon>{}, Set<Polyline> polylines = const <Polyline>{}, Set<Circle> circles = const <Circle>{}, Set<TileOverlay> tileOverlays = const <TileOverlay>{}, Set<Factory< ? gestureRecognizers, Map<OneSequenceGestureRecognizer> >String, dynamic> mapOptions = const <String, dynamic>{}}) → Widget - Returns a widget displaying the map view.
-
buildViewWithConfiguration(
int creationId, PlatformViewCreatedCallback onPlatformViewCreated, {required MapWidgetConfiguration widgetConfiguration, MapConfiguration mapConfiguration = const MapConfiguration(), MapObjects mapObjects = const MapObjects()}) → Widget - Returns a widget displaying the map view.
-
buildViewWithTextDirection(
int creationId, PlatformViewCreatedCallback onPlatformViewCreated, {required CameraPosition initialCameraPosition, required TextDirection textDirection, Set< Marker> markers = const <Marker>{}, Set<Polygon> polygons = const <Polygon>{}, Set<Polyline> polylines = const <Polyline>{}, Set<Circle> circles = const <Circle>{}, Set<TileOverlay> tileOverlays = const <TileOverlay>{}, Set<Factory< ? gestureRecognizers, Map<OneSequenceGestureRecognizer> >String, dynamic> mapOptions = const <String, dynamic>{}}) → Widget - Returns a widget displaying the map view.
-
clearTileCache(
TileOverlayId tileOverlayId, {required int mapId}) → Future< void> -
Clears the tile cache so that all tiles will be requested again from the
TileProvider. -
dispose(
{required int mapId}) → void -
Dispose of whatever resources the
mapIdis holding on to. -
enableDebugInspection(
) → void -
Populates
GoogleMapsFlutterInspectorPlatform.instanceto allow inspecting the platform map state. -
ensureApiInitialized(
int mapId) → MapsApi -
Returns the API instance for
mapId, creating it if it doesn't already exist. -
ensureHandlerInitialized(
int mapId) → HostMapMessageHandler -
Returns the handler for
mapId, creating it if it doesn't already exist. -
getLatLng(
ScreenCoordinate screenCoordinate, {required int mapId}) → Future< LatLng> -
Returns
LatLngcorresponding to theScreenCoordinatein the current map view. -
getScreenCoordinate(
LatLng latLng, {required int mapId}) → Future< ScreenCoordinate> -
Return
ScreenCoordinateof theLatLngin the current map view. -
getStyleError(
{required int mapId}) → Future< String?> -
If the last attempt to set the style via
MapConfiguration.stylefailed, returns the error information, otherwise returns null. -
getVisibleRegion(
{required int mapId}) → Future< LatLngBounds> - Return the region that is visible in a map.
-
getZoomLevel(
{required int mapId}) → Future< double> - Returns the current zoom level of the map.
-
hideMarkerInfoWindow(
MarkerId markerId, {required int mapId}) → Future< void> -
Programmatically hide the Info Window for a
Marker. -
init(
int mapId) → Future< void> -
/// Initializes the platform interface with
id. -
isAdvancedMarkersAvailable(
{required int mapId}) → Future< bool> -
Returns true if
AdvancedMarkers can be used with this map. -
isMarkerInfoWindowShown(
MarkerId markerId, {required int mapId}) → Future< bool> -
Returns
truewhen theInfoWindowis showing,falseotherwise. -
moveCamera(
CameraUpdate cameraUpdate, {required int mapId}) → Future< void> - Changes the map camera position.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onCameraIdle(
{required int mapId}) → Stream< CameraIdleEvent> - The Camera is now idle.
-
onCameraMove(
{required int mapId}) → Stream< CameraMoveEvent> -
The Camera finished moving to a new
CameraPosition. -
onCameraMoveStarted(
{required int mapId}) → Stream< CameraMoveStartedEvent> - The Camera started moving.
-
onCircleTap(
{required int mapId}) → Stream< CircleTapEvent> -
A
Circlehas been tapped. -
onClusterTap(
{required int mapId}) → Stream< ClusterTapEvent> -
A marker icon managed by
ClusterManagerhas been tapped. -
onGroundOverlayTap(
{required int mapId}) → Stream< GroundOverlayTapEvent> -
A
GroundOverlayhas been tapped. -
onInfoWindowTap(
{required int mapId}) → Stream< InfoWindowTapEvent> -
An
InfoWindowhas been tapped. -
onLongPress(
{required int mapId}) → Stream< MapLongPressEvent> -
A Map has been long-pressed at a certain
LatLng. -
onMarkerDrag(
{required int mapId}) → Stream< MarkerDragEvent> -
A
Markerhas been dragged to a differentLatLngposition. -
onMarkerDragEnd(
{required int mapId}) → Stream< MarkerDragEndEvent> -
A
Markerhas been dragged to a differentLatLngposition. -
onMarkerDragStart(
{required int mapId}) → Stream< MarkerDragStartEvent> -
A
Markerhas been dragged to a differentLatLngposition. -
onMarkerTap(
{required int mapId}) → Stream< MarkerTapEvent> -
A
Markerhas been tapped. -
onPolygonEdited(
{required int mapId}) → Stream< PolygonEditEvent> -
A
Polygonpath has been edited by the user. Currently only supported on web.inherited -
onPolygonTap(
{required int mapId}) → Stream< PolygonTapEvent> -
A
Polygonhas been tapped. -
onPolylineEdited(
{required int mapId}) → Stream< PolylineEditEvent> -
A
Polylinepath has been edited by the user. Currently only supported on web.inherited -
onPolylineTap(
{required int mapId}) → Stream< PolylineTapEvent> -
A
Polylinehas been tapped. -
onTap(
{required int mapId}) → Stream< MapTapEvent> -
A Map has been tapped at a certain
LatLng. -
setMapStyle(
String? mapStyle, {required int mapId}) → Future< void> - Sets the styling of the base map.
-
showMarkerInfoWindow(
MarkerId markerId, {required int mapId}) → Future< void> -
Programmatically show the Info Window for a
Marker. -
takeSnapshot(
{required int mapId}) → Future< Uint8List?> - Returns the image bytes of the map.
-
toString(
) → String -
A string representation of this object.
inherited
-
updateCircles(
CircleUpdates circleUpdates, {required int mapId}) → Future< void> - Updates circle configuration.
-
updateClusterManagers(
ClusterManagerUpdates clusterManagerUpdates, {required int mapId}) → Future< void> - Updates cluster manager configuration.
-
updateGroundOverlays(
GroundOverlayUpdates groundOverlayUpdates, {required int mapId}) → Future< void> - Updates ground overlay configuration.
-
updateHeatmaps(
HeatmapUpdates heatmapUpdates, {required int mapId}) → Future< void> - Updates heatmap configuration.
-
updateMapConfiguration(
MapConfiguration configuration, {required int mapId}) → Future< void> - Updates configuration options of the map user interface.
-
updateMapOptions(
Map< String, dynamic> optionsUpdate, {required int mapId}) → Future<void> - Updates configuration options of the map user interface.
-
updateMarkers(
MarkerUpdates markerUpdates, {required int mapId}) → Future< void> - Updates marker configuration.
-
updatePolygons(
PolygonUpdates polygonUpdates, {required int mapId}) → Future< void> - Updates polygon configuration.
-
updatePolylines(
PolylineUpdates polylineUpdates, {required int mapId}) → Future< void> - Updates polyline configuration.
-
updateTileOverlays(
{required Set< TileOverlay> newTileOverlays, required int mapId}) → Future<void> - Updates tile overlay configuration.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
clusterFromPlatformCluster(
PlatformCluster cluster) → Cluster -
Converts a Pigeon
PlatformClusterto the correspondingCluster. -
platformBitmapFromBitmapDescriptor(
BitmapDescriptor bitmap) → PlatformBitmap -
Converts
BitmapDescriptorfrom platform interface toPlatformBitmappigeon. -
platformMapBitmapScalingFromScaling(
MapBitmapScaling scaling) → PlatformMapBitmapScaling -
Converts
MapBitmapScalingfrom platform interface toPlatformMapBitmapScalingPigeon. -
platformMarkerCollisionBehaviorFromMarkerCollisionBehavior(
MarkerCollisionBehavior collisionBehavior) → PlatformMarkerCollisionBehavior -
Converts
MarkersCollisionBehaviorfrom platform interface toPlatformMarkerCollisionBehaviorPigeon. -
registerWith(
) → void - Registers the iOS implementation of GoogleMapsFlutterPlatform.