onLongPress method
Called when the map, not a specifc map object, is long pressed.
Implementation
@override
void onLongPress(PlatformLatLng position) {
streamController.add(
MapLongPressEvent(mapId, _latLngFromPlatformLatLng(position)),
);
}
Called when the map, not a specifc map object, is long pressed.
@override
void onLongPress(PlatformLatLng position) {
streamController.add(
MapLongPressEvent(mapId, _latLngFromPlatformLatLng(position)),
);
}