onTap method
Called when the map, not a specifc map object, is tapped.
Implementation
@override
void onTap(PlatformLatLng position) {
streamController.add(
MapTapEvent(mapId, _latLngFromPlatformLatLng(position)),
);
}
Called when the map, not a specifc map object, is tapped.
@override
void onTap(PlatformLatLng position) {
streamController.add(
MapTapEvent(mapId, _latLngFromPlatformLatLng(position)),
);
}