animateCamera method
Starts an animated change of the map camera position.
The returned Future completes after the change has been started on the platform side.
Implementation
@override
Future<void> animateCamera(CameraUpdate cameraUpdate, {required int mapId}) {
return animateCameraWithConfiguration(
cameraUpdate,
const CameraUpdateAnimationConfiguration(),
mapId: mapId,
);
}