HostMapMessageHandler class
Callback handler for map events from the platform host.
- Annotations
Constructors
-
HostMapMessageHandler(int mapId, StreamController<
MapEvent< streamController, {required TileOverlay? tileOverlayProvider(TileOverlayId tileOverlayId)})Object?> > -
Creates a new handler that listens for events from map
mapId, and broadcasts them tostreamController.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- mapId → int
-
The map ID this handler listens for events from.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
streamController
→ StreamController<
MapEvent< Object?> > -
The controller used to broadcast map events coming from the
host platform.
final
- tileOverlayProvider → TileOverlay? Function(TileOverlayId tileOverlayId)
-
The callback to get a tile overlay for the corresponding map.
final
Methods
-
dispose(
) → void - Removes the handler for native messages.
-
getTileOverlayTile(
String tileOverlayId, PlatformPoint location, int zoom) → Future< PlatformTile> - Called to get data for a map tile.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onCameraIdle(
) → void - Called when the map camera stops moving.
-
onCameraMove(
PlatformCameraPosition cameraPosition) → void - Called when the map camera moves.
-
onCameraMoveStarted(
) → void - Called when the map camera starts moving.
-
onCircleTap(
String circleId) → void - Called when a circle is tapped.
-
onClusterTap(
PlatformCluster cluster) → void - Called when a marker cluster is tapped.
-
onGroundOverlayTap(
String groundOverlayId) → void - Called when a ground overlay is tapped.
-
onInfoWindowTap(
String markerId) → void - Called when a marker's info window is tapped.
-
onLongPress(
PlatformLatLng position) → void - Called when the map, not a specifc map object, is long pressed.
-
onMarkerDrag(
String markerId, PlatformLatLng position) → void - Called when a marker drag updates.
-
onMarkerDragEnd(
String markerId, PlatformLatLng position) → void - Called when a marker drag ends.
-
onMarkerDragStart(
String markerId, PlatformLatLng position) → void - Called when a marker drag starts.
-
onMarkerTap(
String markerId) → void - Called when a marker is tapped.
-
onPolygonTap(
String polygonId) → void - Called when a polygon is tapped.
-
onPolylineTap(
String polylineId) → void - Called when a polyline is tapped.
-
onTap(
PlatformLatLng position) → void - Called when the map, not a specifc map object, is tapped.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited